@@ -9,12 +9,14 @@ class Bot(object):
     '''
     Initializes a new pyrc.Bot.
     '''
+    nick = "PyrcBot" if self.__class__ == Bot else self.__class__.__name__
     self.config = dict(kwargs)
     self.config.setdefault('host', host)
     self.config.setdefault('port', 6667)
-    self.config.setdefault('nick', "HarpBot")
-    self.config.setdefault('ident', "harpbot")
-    self.config.setdefault('realname', "David's Bot")
+    self.config.setdefault('nick', nick)
+    self.config.setdefault('ident', nick.lower())
+    self.config.setdefault('realname', "A Pyrc Bot")
+    self.config.setdefault('channels', [])
 
     self._inbuffer = ""
     self._commands = []
@@ -57,7 +59,10 @@ class Bot(object):
     elif re.match(r"^:\S+ PRIVMSG", line):
       self.parsecommand(line)
     elif line.startswith(":" + self.config['nick']):
-      self.cmd("JOIN #turntechgodhead")
+      # TODO: Improve the above. Should only join on MODE +i or something.
+      if len(self.config['channels']) > 0:
+        channels = ' '.join(self.config['channels'])
+        self.cmd("JOIN " + channels)
 
   def parsecommands(self):
     for func in self.__class__.__dict__.values():
